/*
 *  Copyright (c) Texas Instruments Incorporated 2018-21
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 *  \file cpsw_lld_if.h
 *
 *  \brief CPSW interface private header file.
 */

#ifndef CPSW_LLD_IF_H_
#define CPSW_LLD_IF_H_

/* ========================================================================== */
/*                             Include Files                                  */
/* ========================================================================== */
#include <string.h>
#include <stdio.h>
#include <stdarg.h>
#include <hw/inout.h>
#include <stdint.h>
#include <stdio.h>
#include <unistd.h>
#include <sys/mman.h>
#include <hw/nicinfo.h>
#include <io-pkt/iopkt_driver.h>
#include <sys/io-pkt.h>

#include <ti/osal/osal.h>
#include <ti/drv/uart/UART_stdio.h>
#include <ti/drv/udma/udma.h>

#include <ti/drv/cpsw/cpsw.h>
#include <ti/drv/cpsw/include/dp83867.h>

#include "cpsw_app.h"
#include "cpsw_appmem.h"

#ifdef __cplusplus
extern "C" {
#endif

/* ========================================================================== */
/*                           Macros & Typedefs                                */
/* ========================================================================== */
#ifndef IPC_MPU1_0
#define IPC_MPU1_0                       0
#endif

#ifndef ETH_MAC_ADDR_LEN
/** \brief MAC address length in bytes */
#define ETH_MAC_ADDR_LEN                 (6U)
#endif

/* ========================================================================== */
/*                          Function Declarations                             */
/* ========================================================================== */

void CpswApp_InitObj();
void CpswApp_SetPerferredDmaChNum(uint32_t preferred_udma_channel);
void CpswApp_EnableSmmu(uint32_t virt_id);
void CpswApp_EnableCacheOps();
void CpswApp_SetDescriptorCount(uint32_t tx_descriptors_count,
                                uint32_t rx_descriptors_count);
int32_t CpswApp_GetMacAddr(uint8_t *macAddr);

int32_t CpswApp_PtpInit();
void CpswApp_EventNotifyCallback(void *hEventNotifyCallbackArg,
                                 CpswCpts_Event *eventInfo);
int32_t CpswApp_GetTime(uint64_t *ts);
int32_t CpswApp_SetTime(uint64_t ts);
int32_t CpswApp_GetTimestamp(uint8_t msgType,
                             uint16_t sequenceId,
                             uint8_t tx,
                             uint64_t *ts);
int32_t CpswApp_SetCompensation(int32_t nudge);

int32_t CpswApp_Init(int mac_to_mac, int speed, uint8_t *currentMacAddr);
int32_t CpswApp_InitPhy();
int32_t CpswApp_CheckPortLinkUp(uint32_t timeout_in_sec);
int32_t CpswApp_Close();

void CpswApp_initAleConfig(CpswAle_Config *aleConfig);
uintptr_t CpswApp_disableAllIntr(void);
void CpswApp_restoreAllIntr(uintptr_t key);
void *CpswApp_registerIntr(CpswOsal_IsrFxn isrFxn,
                           uint32_t coreIntrNum,
                           uint32_t intrPriority,
                           void *arg);
void CpswApp_unRegisterIntr(void *hwiHandle);
int32_t CpswApp_openCpsw(int mac_to_mac, int speed, uint8_t *currentMacAddr);
void CpswApp_closeCpsw(void);
void CpswApp_showStats(void);
void CpswApp_rxIsrFxn(void *appData);
void CpswApp_txIsrFxn(void *appData);
int32_t CpswApp_initTxFreePktQ(void);
int32_t CpswApp_initRxReadyPktQ();
int32_t CpswApp_openDma(void);
void CpswApp_closeDma(void);
void CpswApp_changeHostAleEntry(uint8_t macAddr[]);
uint32_t CpswApp_retrieveFreeTxPkts(void);
uint32_t CpswApp_receivePkts(void);

void CpswApp_Tick();
void CpswApp_GetStats(nic_stats_t *stats);
int32_t CpswApp_SendPkt(struct mbuf * m);
int32_t CpswApp_GetRx(void *arg);
uint32_t CpswApp_GetTxFreeQCnt(void);
#if defined (CPSW9G)
void CpswApp_RegisterIPv4Address(uint8_t *ipv4Addr);
void CpswApp_InitSyncTimer(void);
#endif

/* ========================================================================== */
/*                       Static Function Definitions                          */
/* ========================================================================== */

/* None */

#ifdef __cplusplus
}
#endif

#endif /* #ifndef CPSW_LLD_IF_H_ */
