# File: cpsw_component.mk
#       This file is component include make file of CPSW driver library.
# List of variables set in this file and their purpose:
# <mod>_RELPATH        - This is the relative path of the module, typically from
#                        top-level directory of the package
# <mod>_PATH           - This is the absolute path of the module. It derives from
#                        absolute path of the top-level directory (set in env.mk)
#                        and relative path set above
# <mod>_INCLUDE        - This is the path that has interface header files of the
#                        module. This can be multiple directories (space separated)
# <mod>_PKG_LIST       - Names of the modules (and sub-modules) that are a part
#                        part of this module, including itself.
# <mod>_BOARD_DEPENDENCY - "yes": means the code for this module depends on
#                             platform and the compiled obj/lib has to be kept
#                             under <platform> directory
#                             "no" or "" or if this variable is not defined: means
#                             this module has no platform dependent code and hence
#                             the obj/libs are not kept under <platform> dir.
# <mod>_CORE_DEPENDENCY     - "yes": means the code for this module depends on
#                             core and the compiled obj/lib has to be kept
#                             under <core> directory
#                             "no" or "" or if this variable is not defined: means
#                             this module has no core dependent code and hence
#                             the obj/libs are not kept under <core> dir.
# <mod>_APP_STAGE_FILES     - List of source files that belongs to the module
#                             <mod>, but that needs to be compiled at application
#                             build stage (in the context of the app). This is
#                             primarily for link time configurations or if the
#                             source file is dependent on options/defines that are
#                             application dependent. This can be left blank or
#                             not defined at all, in which case, it means there
#                             no source files in the module <mod> that are required
#                             to be compiled in the application build stage.
#
ifeq ($(cpsw_component_make_include), )

drvcpsw_SOCLIST         = am65xx j721e j7200
drvcpsw_BOARDLIST       = am65xx_evm am65xx_idk j721e_evm j7200_evm
drvcpsw_am65xx_CORELIST = mpu1_0 mcu1_0
drvcpsw_j721e_CORELIST  = mpu1_0 mcu1_0 mcu2_0 mcu2_1
drvcpsw_j7200_CORELIST  = mpu1_0 mcu1_0 mcu2_0 mcu2_1
ifeq ($(BUILD_OS_TYPE), qnx)
drvcpsw_j721e_CORELIST += qnx_mpu1_0
endif

############################
# cpsw package
# List of components included under cpsw lib
# The components included here are built and will be part of cpsw lib
############################
cpsw_LIB_LIST =

############################
# cpsw app lib package
# List of components included under cpsw app lib
# The components included here are built and will be part of cpsw app lib
############################
cpsw_APP_LIB_LIST =

############################
# cpsw examples
# List of examples under cpsw (+= is used at each example definition)
# All the tests mentioned in list are built when test target is called
# List below all examples for allowed values
############################
cpsw_EXAMPLE_LIST =

#
# CPSW Modules
#

#
# CPSW library
#
cpsw_COMP_LIST = cpsw
cpsw_RELPATH = ti/drv/cpsw
cpsw_PATH = $(PDK_CPSW_COMP_PATH)
cpsw_LIBNAME = cpsw
cpsw_LIBPATH = $(PDK_CPSW_COMP_PATH)/lib
cpsw_MAKEFILE = -fsrc/makefile
export cpsw_MAKEFILE
export cpsw_LIBNAME
export cpsw_LIBPATH
cpsw_BOARD_DEPENDENCY = no
cpsw_CORE_DEPENDENCY = no
export cpsw_COMP_LIST
export cpsw_BOARD_DEPENDENCY
export cpsw_CORE_DEPENDENCY
cpsw_PKG_LIST = cpsw
cpsw_INCLUDE = $(cpsw_PATH)
cpsw_SOCLIST = $(drvcpsw_SOCLIST)
export cpsw_SOCLIST
cpsw_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export cpsw_$(SOC)_CORELIST
cpsw_LIB_LIST += cpsw

#
# NDK2CPSW adaptation library
nimucpsw_COMP_LIST = nimucpsw
nimucpsw_RELPATH = ti/drv/cpsw/nimucpsw
nimucpsw_PATH = $(PDK_CPSW_COMP_PATH)/nimucpsw
nimucpsw_LIBNAME = nimucpsw
nimucpsw_LIBPATH = $(PDK_CPSW_COMP_PATH)/lib
nimucpsw_MAKEFILE = -fmakefile
export nimucpsw_MAKEFILE
export nimucpsw_LIBNAME
export nimucpsw_LIBPATH
nimucpsw_BOARD_DEPENDENCY = no
nimucpsw_CORE_DEPENDENCY = no
export nimucpsw_COMP_LIST
export nimucpsw_BOARD_DEPENDENCY
export nimucpsw_CORE_DEPENDENCY
nimucpsw_PKG_LIST = nimucpsw
nimucpsw_INCLUDE = $(nimucpsw_PATH)
nimucpsw_SOCLIST = $(drvcpsw_SOCLIST)
export nimucpsw_SOCLIST
nimucpsw_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export nimucpsw_$(SOC)_CORELIST
cpsw_LIB_LIST += nimucpsw

#
# CPSW config server library
cpsw_cfgserver_COMP_LIST = cpsw_cfgserver
cpsw_cfgserver_RELPATH = ti/drv/cpsw/cpsw_cfgserver
cpsw_cfgserver_PATH = $(PDK_CPSW_COMP_PATH)/cpsw_cfgserver
cpsw_cfgserver_LIBNAME = cpsw_cfgserver
cpsw_cfgserver_LIBPATH = $(PDK_CPSW_COMP_PATH)/lib
cpsw_cfgserver_MAKEFILE = -fmakefile
export cpsw_cfgserver_MAKEFILE
export cpsw_cfgserver_LIBNAME
export cpsw_cfgserver_LIBPATH
cpsw_cfgserver_BOARD_DEPENDENCY = no
cpsw_cfgserver_CORE_DEPENDENCY = no
export cpsw_cfgserver_COMP_LIST
export cpsw_cfgserver_BOARD_DEPENDENCY
export cpsw_cfgserver_CORE_DEPENDENCY
cpsw_cfgserver_PKG_LIST = cpsw_cfgserver
cpsw_cfgserver_INCLUDE = $(cpsw_cfgserver_PATH)
cpsw_cfgserver_SOCLIST = $(drvcpsw_SOCLIST)
export cpsw_cfgserver_SOCLIST
cpsw_cfgserver_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export cpsw_cfgserver_$(SOC)_CORELIST
cpsw_LIB_LIST += cpsw_cfgserver


#
# CPSW example library RTOS

cpsw_apputils_COMP_LIST = cpsw_apputils
cpsw_apputils_RELPATH = ti/drv/cpsw/examples/cpsw_apputils
cpsw_apputils_PATH = $(PDK_CPSW_COMP_PATH)/examples/cpsw_apputils
cpsw_apputils_LIBNAME = cpsw_apputils
cpsw_apputils_LIBPATH = $(PDK_CPSW_COMP_PATH)/lib
export cpsw_apputils_OBJPATH = $(cpsw_apputils_RELPATH)/tirtos
cpsw_apputils_MAKEFILE = -fmakefile IS_BAREMETAL=no
export cpsw_apputils_MAKEFILE
export cpsw_apputils_LIBNAME
export cpsw_apputils_LIBPATH
cpsw_apputils_BOARD_DEPENDENCY = yes
cpsw_apputils_CORE_DEPENDENCY = yes
export cpsw_apputils_COMP_LIST
export cpsw_apputils_BOARD_DEPENDENCY
export cpsw_apputils_CORE_DEPENDENCY
cpsw_apputils_PKG_LIST = cpsw_apputils
cpsw_apputils_INCLUDE = $(cpsw_apputils_PATH)
cpsw_apputils_SOCLIST = $(drvcpsw_SOCLIST)
export cpsw_apputils_SOCLIST
cpsw_apputils_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export cpsw_apputils_$(SOC)_CORELIST
cpsw_LIB_LIST += cpsw_apputils

cpsw_apputils_full_COMP_LIST = cpsw_apputils_full
cpsw_apputils_full_RELPATH = ti/drv/cpsw/examples/cpsw_apputils
cpsw_apputils_full_PATH = $(PDK_CPSW_COMP_PATH)/examples/cpsw_apputils
cpsw_apputils_full_LIBNAME = cpsw_apputils_full
cpsw_apputils_full_LIBPATH = $(PDK_CPSW_COMP_PATH)/lib
export cpsw_apputils_full_OBJPATH = $(cpsw_apputils_full_RELPATH)/tirtos_full
cpsw_apputils_full_MAKEFILE = -fmakefile IS_BAREMETAL=no APPUTILS_TYPE=full
export cpsw_apputils_full_MAKEFILE
export cpsw_apputils_full_LIBNAME
export cpsw_apputils_full_LIBPATH
cpsw_apputils_full_BOARD_DEPENDENCY = yes
cpsw_apputils_full_CORE_DEPENDENCY = yes
export cpsw_apputils_full_COMP_LIST
export cpsw_apputils_full_BOARD_DEPENDENCY
export cpsw_apputils_full_CORE_DEPENDENCY
cpsw_apputils_full_PKG_LIST = cpsw_apputils_full
cpsw_apputils_full_INCLUDE = $(cpsw_apputils_full_PATH)
cpsw_apputils_full_SOCLIST = $(drvcpsw_SOCLIST)
export cpsw_apputils_full_SOCLIST
cpsw_apputils_full_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export cpsw_apputils_full_$(SOC)_CORELIST
cpsw_LIB_LIST += cpsw_apputils_full

#
# CPSW example library Baremetal

cpsw_apputils_baremetal_COMP_LIST = cpsw_apputils_baremetal
cpsw_apputils_baremetal_RELPATH = ti/drv/cpsw/examples/cpsw_apputils
cpsw_apputils_baremetal_PATH = $(PDK_CPSW_COMP_PATH)/examples/cpsw_apputils
cpsw_apputils_baremetal_LIBNAME = cpsw_apputils_baremetal
cpsw_apputils_baremetal_LIBPATH = $(PDK_CPSW_COMP_PATH)/lib
export cpsw_apputils_baremetal_OBJPATH = $(cpsw_apputils_RELPATH)/baremetal
cpsw_apputils_baremetal_MAKEFILE = -fmakefile IS_BAREMETAL=yes
export cpsw_apputils_baremetal_MAKEFILE
export cpsw_apputils_baremetal_LIBNAME
export cpsw_apputils_baremetal_LIBPATH
cpsw_apputils_baremetal_BOARD_DEPENDENCY = yes
cpsw_apputils_baremetal_CORE_DEPENDENCY = yes
export cpsw_apputils_baremetal_COMP_LIST
export cpsw_apputils_baremetal_BOARD_DEPENDENCY
export cpsw_apputils_baremetal_CORE_DEPENDENCY
cpsw_apputils_baremetal_PKG_LIST = cpsw_apputils_baremetal
cpsw_apputils_baremetal_INCLUDE = $(cpsw_apputils_baremetal_PATH)
cpsw_apputils_baremetal_SOCLIST = $(drvcpsw_SOCLIST)
export cpsw_apputils_baremetal_SOCLIST
cpsw_apputils_baremetal_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export cpsw_apputils_baremetal_$(SOC)_CORELIST
cpsw_LIB_LIST += cpsw_apputils_baremetal

#
# CPSW soc library

cpsw_soc_COMP_LIST = cpswsoc
cpswsoc_RELPATH = ti/drv/cpsw/soc
cpswsoc_PATH = $(PDK_CPSW_COMP_PATH)/soc
cpswsoc_LIBNAME = cpswsoc
cpswsoc_LIBPATH = $(PDK_CPSW_COMP_PATH)/lib
cpswsoc_MAKEFILE = -fmakefile
export cpswsoc_MAKEFILE
export cpswsoc_LIBNAME
export cpswsoc_LIBPATH
cpswsoc_BOARD_DEPENDENCY = no
cpswsoc_CORE_DEPENDENCY = yes
export cpswsoc_COMP_LIST
export cpswsoc_BOARD_DEPENDENCY
export cpswsoc_CORE_DEPENDENCY
cpswsoc_PKG_LIST = cpswsoc
cpswsoc_INCLUDE = $(cpswsoc_PATH)
cpswsoc_SOCLIST = $(drvcpsw_SOCLIST)
export cpswsoc_SOCLIST
cpswsoc_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export cpswsoc_$(SOC)_CORELIST
cpsw_LIB_LIST += cpswsoc

#
# CPSW Examples
#

# CPSW loopback test app (TI RTOS)
cpsw_loopback_testapp_COMP_LIST = cpsw_loopback_testapp
cpsw_loopback_testapp_RELPATH = ti/drv/cpsw/examples/cpsw_loopback_test
cpsw_loopback_testapp_PATH = $(PDK_CPSW_COMP_PATH)/examples/cpsw_loopback_test
cpsw_loopback_testapp_BOARD_DEPENDENCY = yes
cpsw_loopback_testapp_CORE_DEPENDENCY = yes
cpsw_loopback_testapp_XDC_CONFIGURO = yes
cpsw_loopback_testapp_PKG_LIST = cpsw_loopback_testapp
cpsw_loopback_testapp_INCLUDE = $(cpsw_loopback_testapp_PATH)
cpsw_loopback_testapp_BOARDLIST = $(drvcpsw_BOARDLIST)
cpsw_loopback_testapp_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export cpsw_loopback_testapp_SBL_APPIMAGEGEN = yes
export cpsw_loopback_testapp_COMP_LIST
export cpsw_loopback_testapp_BOARD_DEPENDENCY
export cpsw_loopback_testapp_CORE_DEPENDENCY
export cpsw_loopback_testapp_XDC_CONFIGURO
export cpsw_loopback_testapp_BOARDLIST
export cpsw_loopback_testapp_$(SOC)_CORELIST
cpsw_EXAMPLE_LIST += cpsw_loopback_testapp

# CPSW loopback test app (baremetal)
cpsw_baremetal_loopback_testapp_COMP_LIST = cpsw_baremetal_loopback_testapp
cpsw_baremetal_loopback_testapp_RELPATH = ti/drv/cpsw/examples/cpsw_loopback_test
cpsw_baremetal_loopback_testapp_PATH = $(PDK_CPSW_COMP_PATH)/examples/cpsw_loopback_test
cpsw_baremetal_loopback_testapp_MAKEFILE = -fmakefile IS_BAREMETAL=yes
cpsw_baremetal_loopback_testapp_BOARD_DEPENDENCY = yes
cpsw_baremetal_loopback_testapp_CORE_DEPENDENCY = yes
cpsw_baremetal_loopback_testapp_PKG_LIST = cpsw_baremetal_loopback_testapp
cpsw_baremetal_loopback_testapp_INCLUDE = $(cpsw_baremetal_loopback_testapp_PATH)
cpsw_baremetal_loopback_testapp_BOARDLIST = $(drvcpsw_BOARDLIST)
cpsw_baremetal_loopback_testapp_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export cpsw_baremetal_loopback_testapp_SBL_APPIMAGEGEN = yes
export cpsw_baremetal_loopback_testapp_COMP_LIST
export cpsw_baremetal_loopback_testapp_MAKEFILE
export cpsw_baremetal_loopback_testapp_BOARD_DEPENDENCY
export cpsw_baremetal_loopback_testapp_CORE_DEPENDENCY
export cpsw_baremetal_loopback_testapp_BOARDLIST
export cpsw_baremetal_loopback_testapp_$(SOC)_CORELIST
cpsw_EXAMPLE_LIST += cpsw_baremetal_loopback_testapp

# CPSW NIMU example app
cpsw_nimu_example_COMP_LIST = cpsw_nimu_example
cpsw_nimu_example_RELPATH = ti/drv/cpsw/examples/cpsw_nimu_example
cpsw_nimu_example_PATH = $(PDK_CPSW_COMP_PATH)/examples/cpsw_nimu_example
cpsw_nimu_example_MAKEFILE = -fmakefile
export cpsw_nimu_example_MAKEFILE
cpsw_nimu_example_BOARD_DEPENDENCY = yes
cpsw_nimu_example_CORE_DEPENDENCY = yes
cpsw_nimu_example_XDC_CONFIGURO = yes
export cpsw_nimu_example_SBL_APPIMAGEGEN = yes
export cpsw_nimu_example_COMP_LIST
export cpsw_nimu_example_BOARD_DEPENDENCY
export cpsw_nimu_example_CORE_DEPENDENCY
export cpsw_nimu_example_XDC_CONFIGURO
cpsw_nimu_example_PKG_LIST = cpsw_nimu_example
cpsw_nimu_example_INCLUDE = $(cpsw_nimu_example_PATH)
cpsw_nimu_example_BOARDLIST = $(drvcpsw_BOARDLIST)
export cpsw_nimu_example_BOARDLIST
cpsw_nimu_example_$(SOC)_CORELIST = $(drvcpsw_$(SOC)_CORELIST)
export cpsw_nimu_example_$(SOC)_CORELIST
cpsw_EXAMPLE_LIST += cpsw_nimu_example

-include $(PDK_CPSW_COMP_PATH)/unit_test/cpsw_ut_component.mk
ifneq ($(cpsw_ut_LIB_LIST),)
  cpsw_LIB_LIST += $(cpsw_ut_LIB_LIST)
endif
ifneq ($(cpsw_ut_EXAMPLE_LIST),)
  cpsw_EXAMPLE_LIST += $(cpsw_ut_EXAMPLE_LIST)
endif

ifeq ($(BUILD_OS_TYPE), qnx)
cpsw_LIB_LIST = cpsw cpswsoc
endif
export cpsw_LIB_LIST
export cpsw_EXAMPLE_LIST
export drvcpsw_LIB_LIST = $(cpsw_LIB_LIST)
export drvcpsw_EXAMPLE_LIST = $(cpsw_EXAMPLE_LIST)

CPSW_CFLAGS =

# Enable asserts and prints
CPSW_CFLAGS += -DCPSW_CFG_ASSERT_ENABLE
#CPSW_CFLAGS += -DCPSW_CFG_USE_STD_ASSERT
CPSW_CFLAGS += -DCPSW_CFG_PRINT_ENABLE
CPSW_CFLAGS += -DUART_ENABLED

# Trace level per build profile:
# 0 - None
# 1 - Error
# 2 - Warning
# 3 - Info
# 4 - Debug
# 5 - Verbose
ifeq ($(BUILD_PROFILE),debug)
CPSW_CFLAGS += -DCPSW_TRACE_CFG_TRACE_LEVEL=4
CPSW_CFLAGS += -DCPSW_CFG_DEV_ERROR
CPSW_CFLAGS += -DCPSWDMA_INSTRUMENTATION_ENABLED
CPSW_CFLAGS += -DCPSWCPTS_INSTRUMENTATION_ENABLED
else
CPSW_CFLAGS += -DCPSW_TRACE_CFG_TRACE_LEVEL=3
endif

ifeq ($(BUILD_OS_TYPE), qnx)
CPSW_CFLAGS =
# Enable asserts and prints
CPSW_CFLAGS += -DCPSW_CFG_ASSERT_ENABLE
CPSW_CFLAGS += -DCPSW_CFG_PRINT_ENABLE
CPSW_CFLAGS += -DCPSW_TRACE_CFG_TRACE_LEVEL=4
#CPSW_CFLAGS += -DCPSW_CFG_DEV_ERROR
endif

export CPSW_CFLAGS

cpsw_component_make_include := 1
endif
