/*
 *  Copyright (c) Texas Instruments Incorporated 2018
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*!
 * \file cpsw_trace.c
 *
 * \brief This file has the trace API implementation.
 */

/* ========================================================================== */
/*                             Include Files                                  */
/* ========================================================================== */

#include <stdint.h>
#include <stdarg.h>
#include "priv/cpsw_osal.h"
#include "priv/cpsw_trace_priv.h"

/* ========================================================================== */
/*                           Macros & Typedefs                                */
/* ========================================================================== */

/* None */

/* ========================================================================== */
/*                         Structure Declarations                             */
/* ========================================================================== */

/* None */

/* ========================================================================== */
/*                          Function Declarations                             */
/* ========================================================================== */

/* None */

/* ========================================================================== */
/*                            Global Variables                                */
/* ========================================================================== */

/* None */

/* ========================================================================== */
/*                          Function Definitions                              */
/* ========================================================================== */

#if (CPSW_TRACE_CFG_TRACE_LEVEL > CPSW_TRACE_CFG_LEVEL_NONE)
void CpswTrace_trace(CpswTrace_TraceLevel globalLevel,
                     CpswTrace_TraceLevel level,
                     const char *infoString,
                     ...)
{
    va_list vaArgPtr;

    /* Check if specified level is enabled */
    if (globalLevel >= level)
    {
        va_start(vaArgPtr, infoString);
        CpswUtils_trace((const char *)infoString, vaArgPtr);
        va_end(vaArgPtr);
    }
}

CpswTrace_TraceLevel CpswTrace_setLevel(CpswTrace_TraceLevel level)
{
    CpswTrace_TraceLevel prevLevel = CpswTrace_runtimeLevel;

    CpswTrace_runtimeLevel = level;

    return prevLevel;
}

CpswTrace_TraceLevel CpswTrace_getLevel(void)
{
    return CpswTrace_runtimeLevel;
}

#ifdef QNX_OS
CpswTrace_TraceLevel CpswTrace_runtimeLevel = CPSW_TRACE_DEBUG;
#else
CpswTrace_TraceLevel CpswTrace_runtimeLevel = CPSW_TRACE_INFO;
#endif
#endif
