/*
 *  Copyright (c) Texas Instruments Incorporated 2018
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*!
 * \file     cpsw_ale_priv.h
 *
 * \brief    This file contains the private definitions of the Address Lookup
 *           Engine (ALE).
 */

/*!
 * \addtogroup CPSW_ALE_API
 * @{
 */

#ifndef CPSW_ALE_PRIV_H_
#define CPSW_ALE_PRIV_H_

/* ========================================================================== */
/*                             Include Files                                  */
/* ========================================================================== */
#include "cpsw_osal.h"

#ifdef __cplusplus
extern "C" {
#endif

/*---------------------------------------------------------------------------*\
 |                                Header Files                                 |
 \*---------------------------------------------------------------------------*/

/* Project dependency headers */
#include "cpsw_ale.h"
#include "cpsw_ale_config.h"

/*---------------------------------------------------------------------------*\
 |                           Global Macros/Defines                             |
 \*---------------------------------------------------------------------------*/
#define CPSW_ALE_UNIADDR_ENTRY_DEFAULT_BLOCKEDFLAG  (0U)
#define CPSW_ALE_UNIADDR_ENTRY_DEFAULT_SECUREFLAG   (0U)
#define CPSW_ALE_UNIADDR_ENTRY_DEFAULT_AGEABLEFLAG  (0U)
#define CPSW_ALE_UNIADDR_ENTRY_DEFAULT_TRUNKFLAG    (0U)

#define CPSW_ALE_MCASTADDR_ENTRY_DEFAULT_SUPERFLAG  (0U)
#define CPSW_ALE_MCASTADDR_ENTRY_DEFAULT_FWDSTATE   ( \
                                                     CPSW_ALE_FWDSTLVL_FORWARDING)
#define CPSW_ALE_MCASTADDR_ENTRY_DEFAULT_IGNBITS    (0U)

#define CPSW_ALE_VLAN_ENTRY_DEFAULT_NOLEARNMASK     (0U)
#define CPSW_ALE_VLAN_ENTRY_DEFAULT_VIDINGRESSCHK   (0U)
#define CPSW_ALE_VLAN_ENTRY_DEFAULT_LIMITIPNXTHDR           (0U)
#define CPSW_ALE_VLAN_ENTRY_DEFAULT_DISALLOWFRAGMENTATION   (0U)

/*---------------------------------------------------------------------------*\
 |                           Global Typedefs/Enums                             |
 \*---------------------------------------------------------------------------*/
typedef enum CPSW_ALE_ADDR_TYPE_E
{
    CPSW_ALE_ADDR_TYPE_SRC,
    CPSW_ALE_ADDR_TYPE_DST
} CPSW_ALE_ADDR_TYPE;

/*!
 *  \brief ALE Info Instance Structure
 */
typedef struct CpswAle_Obj_s
{
    /*! Magic value to identify whether object handle is valid or not */
    uint32_t magic;
    /*! Base address of CPSW registers */
    CSL_AleRegs *cpswAleRegBase;
    /*! CPSW IP type                  */
    Cpsw_Type cpswType;
    /*! CPSW in VLAN aware mode.i.e Port Vlan ID enabled */
    bool pvidEnabled;
    /*! Active receive filter settings                                       */
    CPSW_ALE_RXFILTER_E rxFilter;
    /*! Boolean flag to indicate if ALE timer is active                      */
    bool aleSoftTimerActive;
    /*! Current timer count (increments when ALE timer is marked as active)  */
    uint32_t aleSoftTickCount;
    /*! ALE time out count                                                   */
    uint32_t aleTickTimeOutCount;
    /*! ALE functional clock frequency in Hz */
    uint32_t aleFreqHz;

    /*! Default Port VLAN ID
     *                                                   */
    CpswAle_PortVlanConfig pvid[CPSW_ALE_NUM_PORTS];
} CpswAle_Obj;

/*---------------------------------------------------------------------------*\
 |                         Global Variable Declarations                        |
 \*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*\
 |                   Global Inline Function Definitions                        |
 \*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*\
 |                         Global Function Declarations                        |
 \*---------------------------------------------------------------------------*/

/* ========================================================================== */
/*                       Static Function Definitions                          */
/* ========================================================================== */

/* ========================================================================== */
/*                          Function Declarations                             */
/* ========================================================================== */

/* ========================================================================== */
/*                        Deprecated Function Declarations                    */
/* ========================================================================== */

/* None */

#ifdef __cplusplus
}
#endif

#endif /* ALE__H_ */
